//
//  CCoreImageView.h
//  CoreImageTest
//
//  Created by Jonathan Wight on 08/06/2005.
//  Copyright 2005 Toxic Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#import <QuartzCore/QuartzCore.h>

/**
 * @class CCoreImageView
 * @discussion A view that can display a CoreImage image (CIImage). The image can be optionally scaled, aligned and flipped horizontally. Various methods are provided that can be overriden in subclasses to further customise image drawing.
 */
@interface CCoreImageView : NSOpenGLView {
	CIImage *image;

	NSImageScaling scaling;
	NSImageAlignment alignment;
	BOOL flipHorizontal;
	CIFilter *flipHorizontalFilter;

	CIContext *ciContext;
	BOOL needsReshape;
}

- (CIImage *)image;
- (void)setImage:(CIImage *)inImage;

- (NSImageScaling)scaling;
- (void)setScaling:(NSImageScaling)inScaling;

- (NSImageAlignment)alignment;
- (void)setAlignment:(NSImageAlignment)inAlignment;

- (BOOL)flipHorizontal;
- (void)setFlipHorizontal:(BOOL)flag;

/**
 * @method imageToDraw
 * @discussion Override this method in a subclass when 'image' differs from what you want to draw from 'drawImage'. This is useful when extra processing needs to performed before drawing.
 */
- (CIImage *)imageToDraw;

- (CIContext *)ciContext;

- (void)beginDraw;
- (void)drawImage:(NSRect)inRect;
- (void)endDraw;

@end
